==> fred_dnscheck-0.3.0-py3-none-any.whl: dnscheck/tests/process/test_nssets.py <==
import pytest
from asyncstdlib import iter as aiter
from fred_types import NssetId, NssetRef
from pytest_mock import MockFixture
from sqlalchemy import select, text

from dnscheck.db import Nsset, atomic
from dnscheck.process import nssets
from dnscheck.settings import APP


@pytest.fixture
def sync_db(db):
    with atomic() as sess:
        sess.add_all(
            [
                Nsset(nsset_id="A", handle="AAA"),
                Nsset(nsset_id="B", handle="BBB"),
                Nsset(nsset_id="C", handle="CCC"),
                Nsset(nsset_id="D", handle="DDD"),
                Nsset(nsset_id="E", handle="EEE"),
            ]
        )


@pytest.mark.parametrize("batch_size", [1, 2, 100])
def test_sync(sync_db, mocker: MockFixture, batch_size):
    nsset_refs = [
        NssetRef(id=NssetId("A"), handle="AAA"),  # updated
        NssetRef(id=NssetId("B"), handle="BBB"),  # updated
        NssetRef(id=NssetId("X"), handle="XXX"),  # inserted
        NssetRef(id=NssetId("Y"), handle="YYY"),  # inserted
        # C, D and E will be deleted
    ]
    mocker.patch.object(APP.nsset_client, "list", return_value=aiter(nsset_refs))

    nssets.sync(batch_size=batch_size)

    with atomic() as sess:
        nsset_ids = sess.execute(select(Nsset.nsset_id)).scalars().all()
        assert set(nsset_ids) == {"A", "B", "X", "Y"}


def test_sync_locked(db, db_connection: str, mocker: MockFixture):
    if db_connection.startswith("sqlite"):
        pytest.skip("sqlite does not support advisory locks")

    list_mock = mocker.patch.object(APP.nsset_client, "list", return_value=aiter([]))

    with atomic() as sess:
        # create lock
        lock_stmt = text("SELECT pg_try_advisory_xact_lock(:key)").params(key=nssets._LOCK_KEY)
        sess.execute(lock_stmt).scalar_one()

        nssets.sync()

    list_mock.assert_not_called()

==> fred_dnscheck-1.0.0-py3-none-any.whl: dnscheck/tests/process/test_nssets.py <==
import pytest
from asyncstdlib import iter as aiter
from fred_types import NssetId, NssetRef
from pytest_mock import MockFixture
from sqlalchemy import select, text
from testfixtures import OutputCapture

from dnscheck.db import Nsset, atomic
from dnscheck.process import nssets
from dnscheck.settings import APP


@pytest.fixture
def sync_db(db):
    with atomic() as sess:
        sess.add_all(
            [
                Nsset(nsset_id="A", handle="AAA"),
                Nsset(nsset_id="B", handle="BBB"),
                Nsset(nsset_id="C", handle="CCC"),
                Nsset(nsset_id="D", handle="DDD"),
                Nsset(nsset_id="E", handle="EEE"),
            ]
        )


@pytest.mark.parametrize("batch_size", [1, 2, 100])
async def test_sync(sync_db, mocker: MockFixture, batch_size):
    nsset_refs = [
        NssetRef(id=NssetId("A"), handle="AAA"),  # updated
        NssetRef(id=NssetId("B"), handle="BBB"),  # updated
        NssetRef(id=NssetId("X"), handle="XXX"),  # inserted
        NssetRef(id=NssetId("Y"), handle="YYY"),  # inserted
        # C, D and E will be deleted
    ]
    mocker.patch.object(APP.nsset_client, "list", return_value=aiter(nsset_refs))

    with OutputCapture() as output:
        await nssets.sync(batch_size=batch_size)

    with atomic() as sess:
        nsset_ids = sess.execute(select(Nsset.nsset_id)).scalars().all()
        assert set(nsset_ids) == {"A", "B", "X", "Y"}

    output.compare("Summary: 2 inserted, 2 updated, 3 deleted")


async def test_sync_locked(db, db_connection: str, mocker: MockFixture):
    if db_connection.startswith("sqlite"):
        pytest.skip("sqlite does not support advisory locks")

    list_mock = mocker.patch.object(APP.nsset_client, "list", return_value=aiter([]))

    with atomic() as sess:
        # create lock
        lock_stmt = text("SELECT pg_try_advisory_xact_lock(:key)").params(key=nssets._LOCK_KEY)
        sess.execute(lock_stmt).scalar_one()

        with OutputCapture() as output:
            await nssets.sync()

    list_mock.assert_not_called()
    output.compare("Another nsset sync is already running. Aborting.")
